#
# spec file for package ibus-hangul
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ibus-hangul
Version:        1.5.5
Release:        2.5
Summary:        The Hangul engine for IBus input platform
License:        GPL-2.0-or-later
Group:          System/I18n/Korean
URL:            https://github.com/libhangul/ibus-hangul
Source:         https://github.com/libhangul/ibus-hangul/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  gnome-common
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(libhangul)
BuildRequires:  pkgconfig(python3)
Requires:       ibus
Requires:       python3-gobject
# Make sure there is a font available. Pango 1.44 requires
# a scalable font. However, since scalable-font-ko does not
# pull the current default Korean font, Noto Sans KR, thereby
# this spec files specifies its concrete font package name.
Requires:       scalable-font-ko
Recommends:     noto-sans-kr-fonts
Provides:       locale(ibus:ko)

%description
The Hangul engine for IBus platform. It provides Korean input method from
libhangul.

%prep
%setup -q

%build
autoreconf -fi
%configure --disable-static \
           --libexecdir=%{_ibus_libexecdir}
%make_build

%install
%make_install
%suse_update_desktop_file ibus-setup-hangul Utility DesktopUtility System
ln -sf %{_ibus_libexecdir}/ibus-setup-hangul %{buildroot}%{_bindir}/ibus-setup-hangul

%find_lang %{name}
%fdupes %{buildroot}

%files -f %{name}.lang
# /usr/share/licenses is not owned by any package on SLE 12 SP2 and older
%license COPYING
%doc AUTHORS README
%{_bindir}/ibus-setup-hangul
%{_ibus_libexecdir}/ibus-engine-hangul
%{_ibus_libexecdir}/ibus-setup-hangul
%{_ibus_componentdir}/hangul.xml
%{_datadir}/applications/ibus-setup-hangul.desktop
%{_datadir}/icons/hicolor/64x64/apps/ibus-*.png
%{_datadir}/icons/hicolor/scalable/apps/ibus-*.svg
%{_datadir}/%{name}
%{_datadir}/glib-2.0/schemas/org.freedesktop.ibus.engine.hangul.gschema.xml
%{_datadir}/metainfo/org.freedesktop.ibus.engine.hangul.metainfo.xml

%changelog
* Fri Jan 19 2024 Callum Farmer <gmbr3@opensuse.org>
- Fixes for %%_ibus_libexecdir moving to %%_libexecdir (bsc#1174075)
* Thu Jul 20 2023 Dirk Müller <dmueller@suse.com>
- update to 1.5.5:
  * Use synchronous key event processing if possible (since ibus
    1.5.28) (#114 )
  * Update SVG icons
* Mon Mar  1 2021 Marguerite Su <i@marguerite.su>
- add Requires: ibus(boo#1174103)
* Thu Jan 21 2021 Wang Jun <jgwang@suse.com>
- Update to version 1.5.4
  * Fix issue #93
  * Merge Pull Request #99, #96
* Mon Oct  5 2020 Cliff Zhao <qzhao@suse.com>
- Update ibus-hangul.spec: change the copyright to use "SUSE LLC"
  according to the copyright attribution rules in the SUSE Open
  Source Policy.
* Tue Sep 29 2020 tiwai@suse.de
- Replace buildreq gettext-runtime with gettext, which is preferred
  for OBS
* Fri Sep 25 2020 Cliff Zhao <qzhao@suse.com>
- Update ibus-hangul.spec: Add build requirement for gettext-runtime,
  to fix build failure in the integration of SLE-15:SP3.
* Mon Apr 20 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.5.3
  * Fix critical bug #90
  * Fix issue #89
* Wed Apr 15 2020 Cliff Zhao <qzhao@suse.com>
- Update ibus-hangul.spec: Drop the is_opensuse macro to eliminate
  the difference between SLE-15 and openSUSE Leap.
* Sat Jan 11 2020 Fuminobu Takeyama <ftake@geeko.jp>
- Add explanation about recommending Noto Sans KR
* Sun Dec  8 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Make sure at least one font with coverage for korean is installed,
  and can be rendered by Cairo >= 1.44. Fixes boo#1158326.
* Sun Feb 24 2019 i@marguerite.su
- update to version 1.5.2~git20181223.10c4795:
  * Add test code for UString
  * Implement preedit mode option
  * Implement IBusEngine::set_capabilities method
  * Listen to 'use-event-forwarding' option change event
  * Fix event processing priority for hanja conversion
  * Fix interger overflow on h_ibus_text_get_substring()
  * Add AppStream metainfo
  * setup: Add window "destroy" event handling
  * Add Escape to off-keys default value
- changes in 1.5.1
  * correct more spacings
  * correct capitalization of setup labels
  * check if ibus and ibus config is running
  * fix wrong space order problem
  * add disable-latin-mode option
  * setup: set GLib app name explicitly
  * setup: fix PyGI warnings
  * reparent IBusHangulEngine from IBusEngineSimple to handle Compose key
  * migrate IBusConfig to GSettings
  * add use-event-forwarding option
  * setup: Don't use GtkDialog
  * intialized local variable as NULL
  * update initial_input_mode on GSettings "changed"
- use python3
- add python3-gobject as Requires (boo#1124568)
* Thu Oct 23 2014 i@marguerite.su
- update version 1.5.0
  * Add latin input mode. so you can input latin characters without
    changing input method engine.
  * Allow hangul mode to be toggled
  * Python3 compatibility
* Sun Jan 27 2013 hillwood@linuxfans.org
- update to 1.4.2
  * Use Gobject Introspection
  * GNOME Control Center integration
  * Miscellaneous bug fixes
* Mon Oct  1 2012 schwab@linux-m68k.org
- Use %%{_lib} for the installation path
* Wed Jul 18 2012 dvaleev@suse.com
- Fix the installation path of setup program for ppc as well
* Sun Jun 10 2012 hillwood@linuxfans.org
- update to 1.4.1
  * Handle exceptions properly in ibus-setup-hangul
  https://github.com/choehwanjin/ibus-hangul/pull/5
  * Update icon files
  * Support ibus icon symbol feature
* Tue Mar 20 2012 hillwood@linuxfans.org
- update to 1.4.0
  * Require ibus 1.4
  * Add desktop menu for ibus-setup-hangul
  * Add an option for automatic reordering
  * Add an option for a word preedit text
  * Update MS IME compatible symbol table
  * Use surrounding text feature on converting to hanja
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Oct 12 2011 tiwai@suse.de
- Fix build with ibus-1.4, the patch taken from Fedora (bnc#723591)
- Fix the installation path of setup program
* Fri Jul 22 2011 tiwai@suse.de
- Add locale-specific provides tag (bnc#707712)
* Tue Jun 14 2011 swyear@gmail.com
- Update to 1.3.1;
  including fixes for new ibus-1.3.x
* Wed Mar 24 2010 tiwai@suse.de
- fix file list
* Thu Jan 28 2010 mxwu@novell.com
- Initial import
